#delimit ;
capture log close;
log using c:\data\bulg\skouf97\log\clcexp02, replace;
*************************************************************;
*                                                           *;
*    Name    : CLCEXP02.DO              V : 01              *;
*    Date    : May 22,1998                                  *;
*    Infile  : FILE12V1                                     *;
*    Outfile : HHEXPNF1                                     *;
*    Author  : SAJI THOMAS/Mamta Murthi                     *;
*                                                           *;
*    OBJECTIVE: Collapse the data for the non food          *;
*               expenditure file 1 in fewer categories using*;
*               BIHS 1997 -TAKING CARE OF OUTLIERS          *;                                          *;
*************************************************************;

** In several instances the quantity is reported as zero instead of being
   reported as a missing observation.  Moreover the calculated expenditure 
   does not match the reported amount in ~1500 cases. We are going to do a
   rigorous outlier treatment;

clear;

set more 1;
use file12v1;

** Take care of any potentially nasty double-counting 
;
sort hhnum item;
qui by hhnum item: gen a=_n;
tab a;
drop if a>1;
drop a;

** Bring in the stratification file
;
sort hhnum;
merge hhnum using strata;
sort item;

list hhnum if _merge==1;
list hhnum if _merge==2;

drop _merge;
merge item using gitemnf1;
sum;

**STEP0:  Take care of the zero values for prices;

gen flagp1=0;
replace flagp1=1 if price==0 & (quanti>0 & quanti~=.);
replace flagp1=2 if price==0 & (amount>0 & amount~=.);
replace flagp1=3 if price==0 & (amount>0 & amount~=.) & (quanti>0 & quanti~=.);

tab flagp1;

** Price should not be equal to zero if the quantity and
amount reported is greater than zero. We should therefore consider those
cases as missing values;

replace price=. if flagp1>0;


**STEP 1: CALCULATE THE MEAN AND STD DEVIATIONS BY ITEM-
for both price and quantity;

egen mamt=mean(quanti), by(item);
egen samt=sd(quanti), by(item);
egen mprice=mean(price), by(item);
egen sprice=sd(price), by(item);

**STEP 2: CHECK FOR OUTLIERS;

** Check for outliers in both quanitity and price by region 
and locality. We will use the criteria of mean+2std and 3 times mean
to decide upon outliers;

*for prices;
gen flag1=1 if price>mprice+sprice*2 & price~=.;
gen flag2=1 if price>mprice*3 & price~=.;

*for quantity;
gen flag3=1 if quanti>mamt+samt*2 & quanti~=.;
gen flag4=1 if quanti>mamt*3 & quanti~=.;

tab item if flag1==1 & flag2==1;
tab item if flag3==1 & flag4==1;

**STEP 3: Replace the outliers with missing;
replace price=. if flag1==1 & flag2==1;
replace quanti=. if flag3==1 & flag4==1;

drop mamt samt mprice sprice;

** STEP 4: CALCULATE THE MEDIAN PRICE AND QUANTITY;
egen mamt1=median(quanti), by(item distr);
egen mamt2=median(quanti), by(item loc_ty);
egen mamt3=median(quanti), by(item);

egen mprice1=median(price), by(item distr);
egen mprice2=median(price), by(item loc_ty);
egen mprice3=median(price), by(item);
;

**STEP 5: CALCULATE THE PRICE VARIABLE;
gen newpric=price;
replace newpric=price if newpric==.;
replace newpric=mprice1 if newpric==.;
replace newpric=mprice2 if newpric==.;
replace newpric=mprice3 if newpric==.;

gen newqty=quanti;
replace newqty=quanti if newqty==.;
replace newqty=mamt1 if newqty==.;
replace newqty=mamt2 if newqty==.;
replace newqty=mamt3 if newqty==.;

;
gen totexp=newqty*newpric;
gen diff=totexp-amount;

sum diff, detail;

replace totexp=amount if amount~=0 | amount~=.;

sum item newpric price quanti newqty amount totexp;

keep hhnum newpric g_item newqty totexp;
save b40nfood, replace;


collapse (sum) totexp, by(hhnum g_item);
rename totexp nfexp1;

lab var g_item "Group item";
lab var nfexp1 "Non Food Exp. 1";
format nfexp1 %7.2f;
lab data "Non Food 1 Exp.";

save hhexpnf1,replace;

des;
sum;
;
clear;



