#delimit ;
cap log close;
log using c:\data\bulg\skouf97\log\clcexp03,replace;
*************************************************************;
*                                                           *;
*    Name    : CLCEXP03.DO              V : 01              *;
*    Date    : May 25,1998                                  *;
*    Infile  : FILEL13V1                                    *;
*    Outfile : HHEXPNF2                                     *;
*    Author  : C. del Ninno/Mamta Murthi                    *;
*                                                           *;
*    OBJECTIVE: Collapse the data for the non  food         *;
*               expenditure file 2 into fewer categories    *;
*                                                           *;
*************************************************************;

** In this section households were asked to report the value of the purchase
   or the current value.  On the average this difference is pretty big.
   Here we will use the current value estimate, unless there are some
   expenditures that are missing, divided by 12.;

clear;

set more 1;
use file13v1;

** Take care of nasty double counting
;
sort hhnum item;
qui by hhnum item: gen a=_n;
tab a;
drop if a>1;
drop a;

** Bring in the stratification file
;
sort hhnum;
merge hhnum using strata;
sort item;

list hhnum if _merge==1;
list hhnum if _merge==2;

drop _merge;
merge item using gitemnf2;
tab _merge;

list hhnum if _merge==1;
list hhnum if _merge==2;

drop _merge;
sum;

gen dif=(valtoday-cost)*100/cost;
sort item;
by item: sum dif;

**STEP 1: CALCULATE THE MEAN AND STD DEVIATIONS BY ITEM-
for value today;

egen mtoday=mean(valtoday), by(item);
egen stoday=sd(valtoday), by(item);

**STEP 2: CHECK FOR OUTLIERS;

** Check for outliers in value today by region and sector,
We will use the criteria of mean+2std and 3 times mean
to decide upon outliers;

*for value today;
gen flag1=1 if valtoday>mtoday+stoday*2 & valtoday~=.;
gen flag2=1 if valtoday>mtoday*3 & valtoday~=.;

tab item if flag1==1 & flag2==1;

**STEP 3: Replace the outliers with missing;
replace valtoday=. if flag1==1 & flag2==1;

drop mtoday stoday;

** STEP 4: CALCULATE THE MEDIAN PRICE AND valtoday;
egen mtoday1=median(valtoday), by(item distr);
egen mtoday2=median(valtoday), by(item loc_ty);
egen mtoday3=median(valtoday), by(item);

;

**STEP 5: CALCULATE THE TODAY'S VALUE VARIABLE;
gen newval=valtoday;
replace newval=valtoday if newval==.;
replace newval=mtoday1 if newval==.;
replace newval=mtoday2 if newval==.;
replace newval=mtoday3 if newval==.;

;
sum item valtoday;

gen totexp=newval;

gen c1=cost>0 if cost~=.;
gen v1=valtoday>0 if c1==1;
replace v1=0 if valtoday==. & c1==1;

generate val2=valtoday;
replace val2=cost if v1==0;

replace totexp=val2 if val2~=0 | val2~=.;

sum cost totexp valtoday val2;

replace totexp=totexp/12;       /* Create the Monthly values */
keep hhnum g_item totexp;
collapse (sum) totexp, by(hhnum g_item);
rename totexp nfexp2;

lab var g_item "Group item";
lab var nfexp2 "Non Food Exp. 2";
format nfexp2 %7.2f;
lab data "Non Food 2 Exp.";

save hhexpnf2,replace;
des;
sum;
tab g_item, sum(nfexp2);
;
clear;

log close;




