#delimit ;
capture log close;
log using c:\data\bulg\skouf97\log\clcexp04,replace;
*************************************************************;
*                                                           *;
*    Name    : CLCEXP04.DO              V : 01              *;
*    Date    : May 25,1998                                  *;
*    Infile  : FILE07V0, FILE09V0, FILE10V0                 *;
*    Outfile : HHEXPHO                                      *;
*    Author  : C. del Ninno/Mamta Murthi                    *;
*                                                           *;
*    OBJECTIVE: Get the consumption data for housing        *;
*               and utilities-makeing adjustments for       *;
*		outliers using BIHS 97.	                    *;
*                                                           *;
*************************************************************;

** The value of rent WILL NOT BE CALCULATED AT THIS STAGE
   It turns out that less than 5 % of housholds pay rent
   Most people own their house.  The average value for 
   HHs is 10 million Leva (Med=5 million) and the implicit rent reported  
   for  Hhs is 39,000 Leva (Med=15,000).  The implicit rents seem a bit on the
   low side, the annual return is approximately 5 % on average (Med=4%).
;
** There are 113 Hhs that report renting. 65 receive it for free.  
   At this stage I think that the imputed cost of housing should not be included 
   in the calculation of welfare.  An expenditure variable will be calculated 
   using the data on housing related expenditures
;
** Rent is in file 7, housing expenditures in files 9 and 10
;
clear;

set more 1;
use file07v0;
sort hhnum;

merge hhnum using file09v0;
tab _merge;
list hhnum if _merge==1;
list hhnum if _merge==2;

drop _merge;

keep hhnum d_rent hr*;
drop hrs_ele hrs_h2;

** Add telephone expenditure from file 10
;
sort hhnum;
merge hhnum using file10v0;
tab _merge;
list hhnum if _merge==1;
list hhnum if _merge==2;

drop _merge;

drop km* garb q_noi grade;
replace d_fo=0 if q_f==2;
drop q_f;
format hrs* d_f %7.2f;

sort hhnum;
merge hhnum using strata;
tab _merge;
** keep if _merge==3;
** Above line was there in 1995 version but dropped for 1997
   because of problems with missing values

lab data "Housing Exp.";

** Combine few variables
;
gen exprent  = d_rent;
gen expdhea  = hrs_heat; 
gen expelec  = hrs_el; 
gen exphgas  = hrs_gas; 
egen expo_en = rsum(hrs_coal hrs_oil hrs_wood hrs_oene); 
gen expwat   = hrs_wat; 
egen exph_fee= rsum(hrs_wast hrs_tras hrs_cfee); 
gen exptel   = d_fono; 

sum exp* ; 

*** Check for outliers;
** The easiest way is to get the detailed summary of the variable 
and carefully look at each of the variables, one by one to identify the 
outliers;

*Step 1: Check for outliers-by careful observation of the detailed 
summary of each item;

gen flag1=1 if exprent>150000 & exprent~=.;
gen flag2=1 if expdhea>50000 & expdhea~=.;
gen flag3=1 if expelec>50000 & expelec~=.;
gen flag4=1 if exphgas>20000 & exphgas~=.;
gen flag5=1 if expo_en>50000 & expo_en~=.;
gen flag6=1 if expwat>10000 & expwat~=.;
gen flag7=1 if exph_fee>5000 & exph_fee~=.;
gen flag8=1 if exptel>50000 & exptel~=.;

**Step 2: replace outliers with missing;

replace exprent=. if flag1==1;
replace expdhea=. if flag2==1;
replace expelec=. if flag3==1;
replace exphgas=. if flag4==1;
replace expo_en=. if flag5==1;
replace expwat=. if flag6==1;
replace exph_fee=. if flag7==1;
replace exptel=. if flag8==1;

*** Step 3: Calculate the median expenditure;

egen mrent=median(exprent), by(distr);
egen mheat=median(expdhea), by(distr loc_ty);
egen melec=median(expelec), by(distr loc_ty);
egen mgas=median(exphgas), by(distr loc_ty);
egen menergy=median(expo_en), by(distr loc_ty);
egen mwat=median(expwat), by(distr loc_ty);
egen mhfee=median(exph_fee), by(distr loc_ty);
egen mtel=median(exptel), by(distr loc_ty);

**Step 4: Calculate the new housing expenditure variable;
replace exprent=mrent if exprent==.;

** if the median prices are not available then replace by the national median;
replace exprent=2000 if exprent==.;
replace expdhea=mheat if expdhea==.;
replace expdhea=0 if expdhea==.;

replace expelec=melec if expelec==.;

replace exphgas=mgas if exphgas==.;
replace exphgas=0 if exphgas==.;
replace expo_en=menergy if expo_en==.;
replace expwat=mwat if expwat==.;
replace exph_fee=mhfee if exph_fee==.;
replace exptel=mtel if exptel==.;

egen tothexp=rsum(exp*);

sum;
format exp* %7.2f;


keep hhnum tothexp exp*;

lab var exprent  "Exp - N Food - Rent";
lab var expdhea  "Exp - N Food - Distric Heat";
lab var expelec  "Exp - N Food - Electricity";
lab var exphgas  "Exp - N Food - House Gas";
lab var expo_en  "Exp - N Food - O. Energy";
lab var expwat   "Exp - N Food - Water";
lab var exph_fee "Exp - N Food - Trash & O. Fees";
lab var exptel   "Exp - N Food - Telephone";
lab var tothexp "Exp - Total - Housing";

sum;
sort hhnum;
*** make sure there are no duplicates;

qui by hhnum: gen a=_n;
tab a;
drop if a>1;
drop a;

save hhexpho,replace;
des;
sum;
clear;
log close;

