#delimit ;
capture log close;
log using do\clcexp05,replace;
;
*************************************************************;
*                                                           *;
*    Name    : CLCEXP05.DO              V : 01              *;
*    Date    : SEPT 6,1995                                  *;
*    Infile  : FL04V0, FL05V0, FL06V0                       *;
*    Outfile : HHEXPED                                      *;
*    Author  : C. del Ninno and Ramya Sundaram                                *;
*                                                           *;
*    OBJECTIVE: Get the consumption data for education      *;
*                                                           *;
*************************************************************;
;
** The value of training cost spent last 12 months is listed in file No 4.
   In this case there might be a small downward bias because of the 
   expenses are reported on an yearly bases - not estimated at today's 
   value -.  ;

clear;
use file04v0;

keep hhnum fee t_12m;
sort hhnum;
merge hhnum using strata;
tab _merge;

**step 1: check for outliers-by observation  After looking at the data
          it is obvious that only few values are outliers
;
replace t_12m=fee if t_12m>10000 & t_12m~=.;

** step 2: calculate the new variable at household level
;
collapse (sum) t_12m, by(hhnum);
rename t_12m expedtr;

** make it on a monthly basis;

replace expedtr=expedtr/12;
save hhexped,replace;
des;
sum;
clear;

** Add other education expenditure
;
use file06v0;
sort hhnum;
merge hhnum using strata;
tab _merge;
keep if _merge==3;

sum;

lab var d_meals "exp on meals";
keep hhnum distr loc_typ d_*;

**step 1: check for outliers;

gen flag1=1 if d_extrac>1000 & d_extrac~=.;
gen flag2=1 if d_meals>1500 & d_meals~=.;
gen flag3=1 if d_lodge>600 & d_lodge~=.;
gen flag4=1 if d_paper>1000 & d_paper~=.;
gen flag5=1 if d_tuit>5600 & d_tuit~=.;
gen flag6=1 if d_unifor>2000 & d_unifor~=.;
gen flag7=1 if d_books>2200 & d_books~=.;
gen flag8=1 if d_yr>1100 & d_yr~=.;


***step 2: replace outliers with missing values;

replace d_extrac=. if flag1==1;
replace d_meals=. if flag2==1;
replace d_lodge=. if flag3==1;
replace d_paper=. if flag4==1;
replace d_tuit=. if flag5==1;
replace d_unifor=. if flag6==1;
replace d_books=. if flag7==1;
replace d_yr=. if flag8==1;

** step 3: calculate the median expenditures;

egen m_extra=median(d_extrac), by (distr loc_typ);
egen m_meals=median(d_meals), by (distr loc_typ);
egen m_lodge=median(d_lodge), by (distr loc_typ);
egen m_paper=median(d_paper), by (distr loc_typ);
egen m_tuit=median(d_tuit), by (distr loc_typ);
egen m_unifor=median(d_unifor), by (distr loc_typ);
egen m_books=median(d_books), by (distr loc_typ);
egen m_yr=median(d_yr_tut), by (distr loc_typ);


**step 4:  calculate the new education variables, wherin the
missing values are replaced by median values by distr or rural/urban;

replace d_extrac=m_extra if d_extrac==.;
replace d_meals=m_meals if d_meals==.;
replace d_lodge=m_lodge if d_lodge==.;
replace d_paper=m_paper if d_paper==.;
replace d_tuit=m_tuit if d_tuit==.;
replace d_unifor=m_unifor if d_unifor==.;
replace d_books=m_books if d_books==.;

** only 99 observations are there for tutorial exp-only the outliers are
	replaced by their median values;

replace d_yr_tut=m_yr if flag8==1;


format d_*  %7.2f;

sum  d_*;

;
** make the educ expenses monthly-by basic and higher level;
***basic costs includes -tuition, books, uniform, lodging, meals;
*** higher level includes - tutorial expenses;

gen exp1=d_extra + d_mea + d_lod + d_pap + (d_tui + d_uni + d_boo)/12;
lab var exp1 "basic cost";

gen exp2=(d_yr_tut)/12;
lab var exp2 "higher level ed. cost";

egen texp=rsum(exp1 exp2);
lab var texp "total exp on education";

collapse (sum) exp1 exp2 texp, by(hhnum);
rename exp1 basic; 
rename exp2 higher; 
rename texp expeduc; 
merge hhnum using hhexped;
tab _merge;
drop _merge;
format exp* %7.2f;
sort hhnum;
sum;

lab var basic "basic educ. expenses";
lab var higher "quality educ. expenses";
lab var expeduc "Exp - N Food - Education";
lab var expedtr "Exp - N Food - Training";

lab data "HH level Education Exp.";

replace basic=0 if basic==.;
replace higher=0 if higher==.;
replace expeduc=0 if expeduc==.;

save hhexped,replace;
des;
sum;
;
clear;

log close;
