#delimit ;
cap log close;
log using c:\data\bulg\skouf97\log\clcexp07,replace;
*************************************************************;
*                                                           *;
*    Name    : CLCEXP07.DO              V : 01              *;
*    Date    : May 25,1998                                  *;
*    Infile  : FILE47V0                                     *;
*    Outfile :                                              *;
*    Author  : C. del Ninno/M Murthi                        *;
*                                                           *;
*    OBJECTIVE: Use the data for the HH durables            *;
*               to calculate the value of flow of services  *;
*                                                           *;
*************************************************************;
clear;

set more 1;

use file47v0;
drop if a_h==2;
format a_r %10.0f;
tab ass, sum(a_r);
tab ass if a_r==.;

des;

* In the questionnaire we have the estimated resale value of assets which
  approximates its present value.  To calculate the flow of services from 
  these durables we use the rate of return based on the market interest rate. 
  In other words the current value of the asset is treated furnishing the 
  same welfare as the interest earned in the bank.

* Note: there are  - assets without reported value.  Since we don't have 
  the time when the assets were purchased nor the cost at purchase, it is 
  not possible to calculate their present values in any other way.
* For the time being, we will set the value of assets to 0 for those 
  HHs for which we don't have values.  Another alternative is to use
  the median value of the assets by quintiles
;

replace a_res_vl=0 if a_res_vl==.;


*** STEP 1: CALCULATE THE TOTAL VALUE- number of assets * value;

gen totval=a_number*a_res_vl ;

*** STEP 2: Get the total asset value by HHs-all assets;
egen assetval=sum(totval), by(hhnum);


*** STEP 3: Get the flow value of assets on a monthly basis, 
using a 10% rate of interest;

gen flowval=(0.10*assetval)/12;

lab var assetval "Total Hh value of asset";
lab var flowval  "Total flow of services";

*** STEP4: create a category of assets;
gen assetgp=1 if assetcod<=10;
replace assetgp=2 if assetcod>10 & assetcod<=16;
replace assetgp=3 if assetcod>16 & assetcod<=18;
replace assetgp=4 if assetcod>18;
lab var assetgp "asset groups";
lab def assetgp 1 "HH items" 
                2 "entertainment items" 
                3 "vehicles" 
                4 "others";
lab val assetgp assetgp;

keep hhnum assetcod a_number a_re assetgp totval assetval flowval;

*** step 5: calculate the share of type of assets in the 
total income from durables;

gen a=0 ;
replace a=totval if assetgp==1;
egen hhitem=sum(a), by(hhnum);
gen shhh=hhitem/assetval;
drop a;

gen a=0 ;
replace a=totval if assetgp==2;
egen enter=sum(a), by(hhnum);
gen shenter=enter/assetval;
drop a;

gen a=0 ;
replace a=totval if assetgp==3;
egen vehicle=sum(a), by(hhnum);
gen shveh=vehicle/assetval;
drop a;

gen a=0 ;
replace a=totval if assetgp==4;
egen other=sum(a), by(hhnum);
gen shother=other/assetval;
drop a;

sort hhnum;
gen same=0;
replace same=1 if hhnum[_n+1]==hhnum[_n];

keep if same==0;
drop same;


log close;
