#delimit ;
cap log close;
log using c:\data\bulg\skouf97\log\clcexp8a,replace;
*************************************************************;
*                                                           *;
*    Name    : CLCEXP8A.DO              V : 01              *;
*    Date    : June 1,1998                                  *;
*    Infile  : FOODEXP0, HHEXPTLS, HHEXPPCS, HHPOOR         *;
*    Outfile :                                              *;
*    Author  : C. del Ninno/Mamta Murthi                    *;
*                                                           *;
*    OBJECTIVE: Use the data for the HH food exp            *;
*               and construct regional price indices        *;
*                                                           *;
*************************************************************;
clear;

set more 1;

;

** There are regional differences in the cost of living, and 
therefore a regional price index is needed to correct for the fact 
that HHs experience different prices in different areas. The IHS-97
provides data on over 78 food items for the sampled households, 
using which one can construct unit values. However, the construction of
price index for non-food item is not that easy because the non-food items
are too heterogenous for a unit value to be meaningful. As a first step we 
will first construct a regional food price index;

********* METHODOLOGY FOR FOOD PRICE INDEX ***;

**** STEP 1: From the entire national sample of population ranked by the 
nominal per capita expenditure, a sub-sample of botom 40% is identified as
the reference group of population. Only data from this sub-sample are used 
for the construction of the food price index;

**** STEP 2: The selected sub-sample is allocated to the rural and urban 
locality of the nine regions, which defines the reference group of population
for each of the region and locality-However, for the time being we will not
do for sectors (districts?) within regions;

***STEP 3: For sake of homogeneity, we have classified the 78 food items into
7 food groups. This aggregation also takes care of the problem of having too
few observations for some food items for the reference group of population;

***** CONSTRUCTION OF REGIONAL PRICE INDECES;

**** Step 4: select the sub-sample-which is the botton 40 percentile of
the population decile;

use strata;
keep hhnum distr loc_ty loc_sec region month1;
sort hhnum;
merge hhnum using hhexppcs;
tab _merge;
list hhnum if _merge==1;
list hhnum if _merge==2;

drop _merge;
keep hhnum distr loc_ty loc_sec region month1 hhsizer popdecpc;

tab popdecpc [w=hhsizer];
gen bot40=popdecpc<=4;
sort hhnum;
save temp1, replace;

** there are some 2791 individuals in the bottom 40 percentile of the
population-which is the reference group;
tab region loc_ty [w=hhsizer] if bot40==1;
clear;

*** step 5: calculate the mean price by food item groups(g_item), for the
sub-sample, in each of the nine regions seperately. Then, we will
take the ratio of the average regional price to national(sub-sample) average 
price by food group items -call it price ratio;

use foodexp0;
sort hhnum;

merge hhnum using temp1;
tab _merge;
list hhnum if _merge==1;
list hhnum if _merge==2;

drop _merge;

replace totexp=totexp/0.945 if month1==3;
replace totexp=totexp/0.938 if month1==4;
replace totexp=totexp/0.992 if month1==5;
replace totexp=totexp/1.00 if month1==6;
replace totexp=totexp/1.037 if month1==7;
replace totexp=totexp/1.094 if month1==8;
replace totexp=totexp/1.133 if month1==9;

keep if bot40==1 & g_item~=.;
tab region;
*** make 5 food-groups so that it is comparable with the food groups
we have created in the expenditure files-HHEXPTLS;

gen fditem=1 if g_item==1;
replace fditem=2 if g_item==2 | g_item==3;
replace fditem=3 if g_item==4 | g_item==5;
replace fditem=4 if g_item==6 | g_item==7;
replace fditem=5 if g_item==8;
replace fditem=6 if g_item==9;

lab var fditem "food-groups";
lab def fditem 1 "cereal" 2 "fruits & Veg" 3 "Meats & Dairy" 
                4 "Fats & sugars" 5 "Others" 6 "alcohol";

lab val fditem fditem;

**FOR THE REFERENCE GROUP ONLY;
** get the mean price in the nation-by food items;
egen mval=sum(totexp), by(fditem);
egen mqty=sum(quant), by(fditem);
gen mprice=mval/mqty;

lab var mprice "qty weighted-mean national price by food item";

** get the mean price of food groups by regions;
egen rval=sum(totexp), by(fditem region loc_ty);
egen rqty=sum(quant), by(fditem region loc_ty);

gen regprice=rval/rqty;
lab var regprice "qty weighted-mean regional price by food item";


** get the price ratio by food items-regional to national;

gen pratio=regprice/mprice;
lab var pratio "qty weighted-price index";

tab region fditem, sum(mprice) means freq;
tab region fditem, sum(regprice) means freq;
tab region fditem, sum(pratio) means freq;
sort loc_ty;
by loc_ty:tab region fditem, sum(pratio) means freq;

** get a table to calculate the budget shares-this will be done in
excel tables once we have the total expenditures on food groups. 
The price indeces will also be calculated in EXCEL;

egen wtexp=sum(totexp), by(fditem);


tab fditem, sum(wtexp) means freq;
tab fditem if fditem<=5, sum(wtexp) means freq;


clear;

use hhexptls;
sort hhnum;
merge hhnum using hhexppcs;
tab _merge;
list hhnum if _merge==1;
list hhnum if _merge==2;

drop _merge;
sort hhnum;
merge hhnum using strata;

**** Do it for the bottom 40 percentile only;
keep if popdecpc<=4;

**** calculate the food share by food-groups for food-price index;

gen shcer=expcer*100/expfood;
gen shfruit=expfr_ve*100/expfood;
gen shmeat=expme_da*100/expfood;
gen shfat=expfa_su*100/expfood;
gen shofood=expo_fd*100/expfood;

gen fshare=expfood*100/exptot;
sum fshare sh* [w=hhsizer];

tab region loc_ty [w=hhsizer], sum(fshare) means freq;
;


log close;


