#delimit ;
cap log close;
log using c:\data\bulg\skouf97\log\clcexp8b,replace;
*************************************************************;
*                                                           *;
*    Name    : CLCEXP8B.DO              V : 01              *;
*    Date    : June 2,1998                                  *;
*    Infile  : FOODEXP0, HHEXPTLS, HHEXPPCS, HHPOOR         *;
*    Outfile :                                              *;
*    Author  : C. del Ninno/Mamta Murthi                    *;
*                                                           *;
*    OBJECTIVE: Use the data for the HH Non- foodexp        *;
*               and construct regional price indices        *;
*                                                           *;
*************************************************************;
clear;
set more 1;


;
*** In the non-food items we find that we don't have prices for most
of the non-food items. For the non-food items that we do have prices, 
it only constitutes about 36.2% of the non-food expenditure. So we do have
a problem. One way might be to scale the non-food expenditures by a 
proportion (=2.75) so that it becomes equal to 100. The non-food 
items ( 6 items) for which we have prices are as follows: 

Alcohol
Tobacco, 
personal, 
cleaning, and
gasoline.

The methodology for calculating the non-food price index 
will be the same as that of the food price index;


;

********* NON-FOOD PRICE INDEX ***;

**** STEP 1: From the entire national sample of population ranked by the 
nominal per capita expenditure, a sub-sample of botom 40% is identified as
the reference group of population. Only data from this sub-sample are used 
for the construction of the food price index;

**** STEP 2: The selected sub-sample is allocated to the rural and urban 
locality of the nine regions, which defines the reference group of population
for each of the region and locality-However, for the time being we will not
do for sectors within regions;

***STEP 3: For sake of homogeneity, we have classified the non-food items into
5 food groups. This aggregation also takes care of the problem of having too
few observations for some non-food items for the reference group of population;

***** CONSTRUCTION OF REGIONAL PRICE INDECES;

**** Step 4: select the sub-sample-which is the botton 40 percentile of
the population decile;

use strata;
keep hhnum distr loc_ty loc_sec region month1; 
sort hhnum;
merge hhnum using hhexppcs;
tab _merge;
list hhnum if _merge==1;
list hhnum if _merge==2;

drop _merge;
keep hhnum distr loc_ty loc_sec region month1 hhsizer popdecpc;

tab popdecpc [w=hhsizer];
gen bot40=popdecpc<=4;
sort hhnum;
save ntemp1, replace;

** there are some 2791 individuals in the bottom 40 percentile of the
population-which is the reference group;
tab region loc_ty [w=hhsizer] if bot40==1;
clear;

*** step 5: calculate the mean price by food item groups(g_item), for the
sub-sample, in each of the nine regions seperately. Then, we will
take the ratio of the average regional price to national(sub-sample) average 
price by food group items -call it price ratio;

use b40nfood;
sort hhnum;
merge hhnum using ntemp1;
tab _merge;
list hhnum if _merge==1;
list hhnum if _merge==2;

drop _merge;

replace totexp=totexp/0.945 if month1==3;
replace totexp=totexp/0.938 if month1==4;
replace totexp=totexp/0.992 if month1==5;
replace totexp=totexp/1.00 if month1==6;
replace totexp=totexp/1.037 if month1==7;
replace totexp=totexp/1.094 if month1==8;
replace totexp=totexp/1.133 if month1==9;

keep if bot40==1 & g_item~=.;
tab region;
*** select the 5 nonfood-groups for which we have prices;

gen nfditem=1 if g_item==21;
replace nfditem=2 if g_item==23;
replace nfditem=3 if g_item==24;
replace nfditem=4 if g_item==25;

lab var nfditem "nonfood-groups";
lab def nfditem 1 "tobacco" 2 "personal" 3 "cleaning" 
                4 "gasoline";

lab val nfditem nfditem;


** get the mean price in the nation-by food items;
egen mval=sum(totexp), by(nfditem);
egen mqty=sum(newqty), by(nfditem);
gen mprice=mval/mqty;


** get the mean price of non-food groups by regions;
egen rval=sum(totexp), by(nfditem region loc_ty);
egen rqty=sum(newqty), by(nfditem region loc_ty);
gen regprice=rval/rqty;


*** get the price ratio-the ratio of average price of a food group 
in a region to the national price(of sub-sample);

gen pratio=regprice/mprice;
lab var pratio "food price index";

tab region nfditem, sum(mprice) means freq;
tab region nfditem, sum(regprice) means freq;
tab region nfditem, sum(pratio) means freq;
sort loc_ty;
by loc_ty:tab region nfditem, sum(pratio) means freq;


*** get the budget shares-we can create them in EXCEL once we have the total
expenditure by non-food groups;

egen wtall=sum(totexp), by(nfditem);
tab nfditem, sum(wtall) means freq;



/*

Notice that we have prices for non-food items that only account for 34.6% of
the total non-food expenditure;

Next, multiply the budget shares by the price ratio, seperately 
for each region and then sum it over all the food items to get the seperate price
index for all the regions-DONE IN EXCEL TABLE;
*/


clear;


use hhexptls;
sort hhnum;
merge hhnum using hhexppcs;
tab _merge;
list hhnum if _merge==1;
list hhnum if _merge==2;

drop _merge;
sort hhnum;
merge hhnum using strata;

**** Do it for the bottom 40 percentile only;
keep if popdecpc<=4;

**** calculate the non-food share by groups for non-food index;
;

gen shalch=expalch*100/expnfood;
gen shtob=exptob*100/expnfood;
gen shper=expper*100/expnfood;
gen shclean=expclea*100/expnfood;
gen shgaso=expgaso*100/expnfood;
gen shtran=exptra*100/expnfood;
gen nfshare=expnfood*100/exptot;

format sh* %4.2f;

sum exp* sh* nfshare [w=hhsizer];
tab region loc_ty [w=hhsizer], sum(nfshare) means freq;
;

log close;

