#delimit ;
capture log close;
log using c:\data\bulg\skouf97\log\clcexpps,replace;
*************************************************************;
*                                                           *;
*    Name    : CLCEXPPS.DO              V : 01              *;
*    Date    : June 1,1998                                  *;
*    Infile  : HHEXPTLS, HHSIZE                             *;
*    Outfile : HHEXPPCS                                     *;
*    Author  : C. del Ninno/M Murthi                        *;
*                                                           *;
*    OBJECTIVE: Get the total variables from the tl file and *;
*               create pc & ae variables and deciles        *;
*               -Adjusted for seasonality and inflation-    *;
*************************************************************;
set more 1;
clear;
use hhexptls;
sum;
keep hhnum expfo expnfoo exptot;

** For now use the Pc and Ae Variable
;
merge hhnum using hhsize;
tab _merge;
list hhnum if _merge==1;
list hhnum if _merge==2;

keep if hhnumber~=.;

drop _merge;
gen pcexp=exptot/hhsizer;
lab var pcexp "Per Capita - Total Expenditure - Res";
format pce %10.2f;

gen aeexp=exptot/adult;
lab var aeexp "Adult Equiv - Total Expenditure - Res";
format aeex %10.2f;

sum;

** Calculate deciles of households based on the PC expenditure
   As usual, the ranking is done for Hhs and the variables used
   is the Pc expenditure.  All poverty measured involving individuals 
   should be calculated using size weights
;
sum pcexp,det;    /* Notice the outlier excluded later */
sort pcexp;
gen hhdecpc=group(10) if pcexp>100 & pcexp <2000000 ;
lab var hhde "Hh level Pc Exp. Decile";

sort aeexp;
gen hhdecae=group(10) if pcexp>100 & pcexp <2000000 ;
lab var hhdecae "Hh level Ae Exp. Decile";


lab define decile
       1  "decile 1"
        2  "decile 2"
        3  "decile 3"
        4  "decile 4"
        5  "decile 5"
        6  "decile 6"
        7  "decile 7"
        8  "decile 8"
        9  "decile 9"
        10 "decile10"
;
lab value hhdecpc decile;
lab value hhdecae decile;

** Get few tables on Per capita basis
;
tab hhdecpc, sum(hhsizer);
tab hhdecpc, sum(hhsizea) ;
tab hhdecpc [w=hhsizer], sum(pce) ;
tab hhdecpc [w=hhsizer], sum(aee) ;
tab hhsizer, sum(pce);

** Get few tables on Adult Equivalent basis
;
tab hhdecae, sum(hhsizer);
tab hhdecae, sum(hhsizea) ;
tab hhdecae [w=hhsizer], sum(aee) ;
tab hhdecae [w=hhsizer], sum(pce) ;

** Calculate deciles of individuals based on the PC expenditure
   The ranking is done for Hhs adding up the number of people in 
   each household and the variables used is the Pc expenditure.  
   Even in this case poverty measured involving individuals should be 
   calculated using Hhsize as weights
;
sort pcexp;
gen poppc=sum(hhsizer) if pcexp>100 & pcexp <2000000;
sum poppc;
local pmin=_result(5);
local pmax=_result(6);
local pint=int(`pmax'/10);
gen popdecpc=autocode(poppc,10,`pmin',`pmax');
replace popdecpc=int(popdecpc/`pint');
lab var popdecpc "Pop level Pc Exp. Decile";

sort aeexp;
gen popae=sum(hhsizer) if pcexp>100 & pcexp <2000000;
sum popae;
local pmin=_result(5);
local pmax=_result(6);
local pint=int(`pmax'/10);
gen popdecae=autocode(popae,10,`pmin',`pmax');
replace popdecae=int(popdecae/`pint');
lab var popdecae "Pop level Ae Exp. Decile";

lab value popdecpc decile;
lab value popdecae decile;

drop poppc popae;

** SAVE THE FILE
;
lab data "Per Capita expenditure";
sort hhnum;
save hhexppcs, old replace;
log close;
