#delimit ;
capture log close;
log using c:\data\bulg\skouf97\log\clcexptl,replace;
*************************************************************;
*                                                           *;
*    Name    : CLCEXPTL.DO              V : 01              *;
*    Date    : May 25,1998                                  *;
*    Infile  : HHEX FILES                                   *;
*    Outfile : HHEXPTL                                      *;
*    Author  : C. del Ninno/M Murthi                        *;
*                                                           *;
*    OBJECTIVE: Combine individual expenditure files in one *;
*               expenditure file suing BIHS 1997            *;
*                                                           *;
*************************************************************;
set more 1;

**  Start with the food expenditure file - Reduce to fewer commodities
;
clear;

use hhexpf;

* Create a little program to read the expenditure items,
  collapse into fewer groups and present them at Hh level.
;
# delimit cr;
cap prog drop doit
prog define doit
     local varexp ="`1'"
     mac shift
     local varname ="`1'"
     mac shift
     gen a=0
     while "`1'" ~="" {
        replace a=`varexp' if g_item==`1' 
        mac shift
     }   
     egen `varname'=sum(a), by(hhnum)
     drop a
end
#delimit ;

doit foodexp expcer 1     ;
doit foodexp expfr_ve 2 3 ;
doit foodexp expme_da 4 5 ;
doit foodexp expfa_su 6 7 ;
doit foodexp expo_fd 8    ;
doit foodexp expalch 9    ;


lab var expcer   "Exp - Food - Cereal";
lab var expfr_ve "Exp - Food - Fru & Veg";
lab var expme_da "Exp - Food - Meat & Dairy";
lab var expfa_su "Exp - Food - Fats & Sugar";
lab var expo_fd  "Exp - Food - Other";
lab var expalch  "Exp - N Food - Alcohol";

** Collapse the observations at the household level
;
sort hhnum;
qui by hhnum: gen a=_n;
keep if a==1;

keep hhnum exp*;
egen expfood=rsum(exp*);
replace expfood=expfood-expalch;

lab var expfood "Exp - Food - Total";

format exp* %7.2f;
des;
sum;

save hhexptl,replace;

** Add Non Food Expenditure 1 
;
use hhexpnf1;

doit nfexp1 exptob   21 ;
doit nfexp1 expent1  22 ;
doit nfexp1 expper   23 ;
doit nfexp1 expclea  24 ;
doit nfexp1 expgaso  25 ;
doit nfexp1 exptra   26 ;
doit nfexp1 expto_nf 27 ;

lab var exptob   "Exp - N Food - Tobacco";
lab var expent1  "Exp - N Food - Enter 1";
lab var expper   "Exp - N Food - Personal";
lab var expclea  "Exp - N Food - Cleaning";
lab var expgaso  "Exp - N Food - Gasoline";
lab var exptra   "Exp - N Food - Transport";  /*Includes car repairs*/;
lab var expto_nf "Exp - N Food - Other";

** Collapse the observations at the household level
;
sort hhnum;
qui by hhnum: gen a=_n;
keep if a==1;
keep hhnum exp*;
format exp* %7.2f;

sort hhnum;
des;
sum;
save tp01,replace;

use hhexptl;
merge hhnum using tp01;
tab _merge;
list hhnum if _merge==1;
list hhnum if _merge==2;
drop _merge;

sort hhnum;
save hhexptl,replace;

*
** Add Non Food Expenditure 2
;
use hhexpnf2;
                     
doit nfexp2 expclo   31 ;
doit nfexp2 expheal  32 ;
doit nfexp2 expfur_a 33 34 ;
doit nfexp2 expent2  35 ;
doit nfexp2 expins   36 ;
doit nfexp2 expsav   37 ;
doit nfexp2 exphrep  38 ;

lab var expclo  "Exp - N Food - Clothing ";
lab var expheal "Exp - N Food - Health ";
lab var expfur  "Exp - N Food - Furn. & Appl.";
lab var expent2 "Exp - N Food - Enter 2";
lab var expins  "Exp - N Food - Insurance";
lab var expsav  "Exp - N Food - Savings";
lab var exphrep "Exp - N Food - House repair";

** Collapse the observations at the household level
;
sort hhnum;
qui by hhnum: gen a=_n;
keep if a==1;
keep hhnum exp*;
format exp* %7.2f;
sort hhnum;
des;
sum;
save tp02,replace;

clear;

use hhexptl;
merge hhnum using tp02;
tab _merge;
list hhnum if _merge==1;
list hhnum if _merge==2;
drop _merge;

** Some households might not consume some of the items
   therefore they have to set to zero and not missing
;
* Modify some variables
; 
replace exptob  =0 if exptob  ==.;
replace expent1 =0 if expent1 ==.; 
replace expper  =0 if expper  ==.; 
replace expclea =0 if expclea ==.; 
replace expgaso =0 if expgaso ==.; 
replace exptra  =0 if exptra  ==.; 
replace expto_nf=0 if expto_nf==.; 

*Modify some variables
;
replace expclo=0  if expclo==.;
replace exphea=0  if exphea==.;
replace expfur=0  if expfur==.;
replace expent2=0 if expent2==.;
replace expins=0  if expins==.;
replace expsav=0  if expsav==.;
replace exphrep=0 if exphrep==.;

egen expent=rsum(expent1 expent2) ;         /* Combine the two */;
lab var expent "Exp - N Food - Entertain";
drop expent1 expent2;

** Add variables from Education and Housing
;
sort hhnum;
merge hhnum using hhexpho;
tab _merge;
list hhnum if _merge==1;
list hhnum if _merge==2;
drop _merge;

sort hhnum;
merge hhnum using hhexped;
tab _merge;
list hhnum if _merge==1;
list hhnum if _merge==2;
drop _merge;

save,replace;

** Calculate the total Expenditure by Household
;
gen expnfood= expalch + exptob  + expper
            + expclea + expgaso + exptra  + expto_nf
            + expclo  + expheal + expfur  + expins  + exphrep 
            + exprent  
            + expdhea + expelec + exphgas + expo_en + expwat  
            + exph_fee+ exptel  
            + expeduc + expedtr ;

gen exptot= expfood + expnfood;

format exp* %7.2f;

lab var expnfood "Exp - N Food - Total";
lab var exptot   "Exp - Total Month Hh";
sort hhnum;

lab data "HH Mo. Expenditure";
save, old replace;
des; 
sum;


** Clean up
;
prog drop doit;
erase tp01.dta;
erase tp02.dta;

log close;


