#delimit ;
capture log close;
log using c:\data\bulg\skouf97\log\clcexpts,replace;
*************************************************************;
*                                                           *;
*    Name    : CLCEXPTS.DO              V : 01              *;
*    Date    : June 1,1998                                  *;
*    Infile  : HHEXPTL, HHSIZE, STRATA, ADJUST2W            *;
*    Outfile : HHEXPTLS                                     *;
*    Author  : C. del Ninno/M Murthi                        *;
*                                                           *;
*    OBJECTIVE: Get the total variables for the tl file and *;
*               adjust the expenditure level for inflation  *;
*               and using seasonal consumption patterns     *;   
*                                                           *;  
*************************************************************;
set more 1;
clear;
use hhexptl;
sum;

** Calculate the deciles to match adjustment factors - use the Pc Variable
;
merge hhnum using hhsize;
tab _merge;
list hhnum if _merge==1;
list hhnum if _merge==2;

drop _merge;

sort hhnum;
merge hhnum using strata;
tab _merge;
list hhnum if _merge==1;
list hhnum if _merge==2;

drop _merge pop_grou langua;

gen pcexp=exptot/hhsizer;
replace pcexp=pcexp/0.945 if month1==3;
replace pcexp=pcexp/0.938 if month1==4;
replace pcexp=pcexp/0.992 if month1==5;
replace pcexp=pcexp/1.00 if month1==6;
replace pcexp=pcexp/1.037 if month1==7;
replace pcexp=pcexp/1.094 if month1==8;
replace pcexp=pcexp/1.133 if month1==9;

lab var pcexp "Per Capita - Total Expenditure - Res";
format pce %10.2f;

** Calculate deciles of households based on the PC expenditure
   As usual, the ranking is done for Hhs and the variables used
   is the Pc expenditure.  
;
sort pcexp;
gen hhdecpc=group(10);
lab var hhde "Hh level Pc Exp. Decile";

gen gdec=0;
replace gdec=1 if hhdec<=2;
replace gdec=2 if hhdec>2 & hhdec<9 ;
replace gdec=3 if hhdec>8 & hhdec~=.;
tab gdec;

** Make some changes
;

rename loc_sec locn;
rename month1 monthc;

** Get the seasonal adjustment factor
   The adjustment factor was calculated using the HH Budget 
   survey data of 94.  The same patterns of monthly consumption that 
   were observed for Sofia, O.Urban and Rural Hhs in three 
   expenditure categories - Bottom 20%, Middle 60% and top 20% -
   were applied to the 97 data that was collected over a period of
   only 9 months (March - Sept), with the bulk of the hhlds sampled
   in May and June 
;
sort locn monthc gdec;
merge locn monthc gdec using adjust2w;
tab _merge;
list hhnum if _merge==1;
list hhnum if _merge==2;

drop if _merge==2;

drop _merge;

** Adjust the variables that need adjustment
;
replace expcer  =expcer  /factor1 ;  /*Exp - Food - Cereal            */
replace expfr_ve=expfr   /factor3 ;  /*Exp - Fruits & Vegetables      */
replace expme_da=expme   /factor2 ;  /*Exp - Food - Meat & Dairy      */
replace expfa_su=expfa   /factor4 ;  /*Exp - Food - Fats & Sugar      */
replace expo_fd =expo_f  /factor5 ;  /*Exp - Food - Other             */
replace expalch =expalch /factor6 ;  /*Exp - N Food - Alcohol         */

replace exptob  =exptob  /factor25;  /*Exp - N Food - Tobacco         */
replace expper  =expper  /factor23;  /*Exp - N Food - Personal        */
replace expclea =expcle  /factor22;  /*Exp - N Food - Cleaning        */
replace expgaso =expgaso /factor14;  /*Exp - N Food - Gasoline        */
replace exptra  =exptra  /factor15;  /*Exp - N Food - Transport       */
replace expto_nf=expto_n /factor24;  /*Exp - N Food - Other           */

*replace expent  =expent  /factor ?;  /*Exp - N Food - Entertain       */
*replace exprent =exprent /factor ?;  /*Exp - N Food - Rent            */

replace expdhea =expdhea /factor8 ;  /*Exp - N Food - Distric Heat    */
replace expelec =expelec /factor7 ;  /*Exp - N Food - Electricity     */
replace exphgas =exphgas /factor9 ;  /*Exp - N Food - House Gas       */
replace expo_en =expo_en /factor9 ;  /*Exp - N Food - O. Energy       */
replace expwat  =expwat  /factor11;  /*Exp - N Food - Water           */
replace exph_fee=exph_fe /factor10;  /*Exp - N Food - Trash & O. Fees */
replace exptel  =exptel  /factor12;  /*Exp - N Food - Telephone       */
*replace expedtr =expedtr /factor ?;  /*                                */

** RECALCULATE THE TOTAL
;

replace expfood = expcer + expfr_ve + expme_da + expfa_su
                     + expo_fd ;

replace expnfood= expalch + exptob  + expper
                + expclea + expgaso + exptra  + expto_nf
                + expclo  + expheal + expfur  + expins  + exphrep 
                + expent  
                + expdhea + expelec + exphgas + expo_en + expwat  
                + exph_fee+ exptel  
                + expeduc + expedtr ;

replace exptot= expfood + expnfood;


** CLEAN UP AND SAVE THE FILE
;
keep hhnum exp*;

lab data "Total Adjusted Expenditure";
sort hhnum;
sum;

save hhexptls, old replace;
log close;
