# delimit;
capture log close;
log using c:\data\bulg\skouf97\log\mkpoord.log, replace;
*************************************************************;
*                                                           *;
*    Name    : MKPOORD.DO               V : 01              *;
*    Date    : May 25, 1998                                 *;
*    Infile  : HHEXPPCD                                     *;
*    Outfile : HHPOORD                                      *;
*    Author  : C. del Ninno/M Murthi                        *;
*                                                           *;
*    OBJECTIVE: Get the poor/non-poor file based on         *;
*               both pc expenditure variables: Deflated     *;
*************************************************************;
clear;

set more 1;

use hhexppcd;
sort hhnum;
sum [w=hhsizer];

** Add calculation of quintiles
;
** Household based
;
sort pcexp;
gen hhquipc=group(5) if pcexp>100 & pcexp <2000000 ;
lab var hhquipc "Hh level Pc Exp. Quintile";

sort aeexp;
gen hhquiae=group(5) if pcexp>100 & pcexp <2000000 ;
lab var hhquiae "Hh level Ae Exp. Quintile";

** Population based
;
sort pcexp;
gen poppc=sum(hhsizer) if pcexp>100 & pcexp <2000000;

sum poppc;
local pmin=_result(5);
local pmax=_result(6);
local pint=int(`pmax'/5);

gen popquipc=autocode(poppc,5,`pmin',`pmax');
replace popquipc=int(popquipc/`pint');
lab var popquipc "Pop level Pc Exp. Quintile";

sort aeexp;
gen popae=sum(hhsizer) if pcexp>100 & pcexp <2000000;

sum popae;
local pmin=_result(5);
local pmax=_result(6);
local pint=int(`pmax'/5);

gen popquiae=autocode(popae,5,`pmin',`pmax');
replace popquiae=int(popquiae/`pint');
lab var popquiae "Pop level Ae Exp. Quintile";

drop poppc popae;

lab define quintile
        1 "quint 1"
        2 "quint 2"
        3 "quint 3"
        4 "quint 4"
        5 "quint 5";
;
lab value hhquipc quintile;
lab value hhquiae quintile;
lab value popquipc quintile;
lab value popquiae quintile;


                    ***   POVERTY LINE ***
** Based on the two-third mean per capita exp;
** The inflation adjusted poverty line for 1997 was 69554.86, which is
 derived as 69554.86= 0.67*26.36*3956, where 3956 is the MPC in 1995,
 and 26.36 is the price inflation.  
 ;
local z=69554.86;       /* Poverty line */
 
gen pcpoor= pcexp<=`z';

gen pcp1=0;
replace pcp1=(`z'-pcexp)/`z' if pcpoor==1;
       /*P1 or depth of poverty*/ 

gen pcp2=0;
replace pcp2=((`z'-pcexp)/`z')^2 if pcpoor==1;
      /*P2 or severity of poverty*/ 

lab var pcpoor "PC Exp Poverty";
lab var pcp1 "PC Poverty depth";
lab var pcp2 "PC Poverty severity";

replace pcpoo=pcpo*100;
replace pcp1=pcp1*100;
replace pcp2=pcp2*100;
format pcp* %5.2f;

lab define pcpoor   0 "Non-Poor"  
                    1 "Poor";
lab valu pcpoor pcpoor;

sort hhnum;
lab data "Poor-nonpoor file";
save hhpoord, old replace;

tab pcpoor [w=hhsizer];
/*run n:\stata\ado\disperse\gini.ado;
gini pcexp, wt(hhsizer);*/

;
log close;
